# frozen_string_literal: true

module TeleportCookbook
  include Chef::Mixin::ShellOut

  class WaitCommandTimeoutError < StandardError; end

  #
  # Implements the `stream_command` which allows you to run a command and get
  # its output in real-time.
  #
  module StreamCommand
    def wait_command_output(command, match_regex, options = {})
      options[:timeout] ||= 60

      previous_container_status = nil
      try_count = 0

      until previous_container_status =~ match_regex
        command_output = shell_out(command).stdout.gsub(/\n/, '')

        unless previous_container_status == command_output
          previous_container_status = command_output

          yield command_output if block_given?
        end

        try_count += 1

        raise WaitCommandTimeoutError if try_count >= options[:timeout]

        sleep 1
      end
    end
  end
end
